autowisp.database.data_model.hdf5_products module — AutoWISP documentation

# autowisp.database.data_model.hdf5_products module

## Class Inheritance Diagram

Define the hdf5_attributes table.

class autowisp.database.data_model.hdf5_products.HDF5Product(**kwargs)

  Bases: `DataModelBase`

  The types of pipeline products stored as HDF5 files.

  description

    A description of the product type.

  id

    A unique identifier for each row.

  pipeline_key

    How is this product referred to in the pipeline (e.g. “datareduction” or “lightcurve”

  structure_versions
  timestamp

    When record was last changed